@@ -25,31 +25,27 @@ Host adder plugin.
 import gettext
 import os
 import selinux
+import socket
 import tempfile
 import time
 
-
-import ovirtsdk.api
-import ovirtsdk.infrastructure.errors
-import ovirtsdk.xml
-
-
 from otopi import constants as otopicons
 from otopi import filetransaction
 from otopi import plugin
 from otopi import transaction
 from otopi import util
 
-
-from vdsm.network.netinfo.cache import CachingNetInfo
-
-
 from ovirt_host_deploy import constants as ohdcons
+
+from ovirt_hosted_engine_setup import constants as ohostedcons
 from ovirt_hosted_engine_setup import check_liveliness
 from ovirt_hosted_engine_setup import engineapi
-from ovirt_hosted_engine_setup import constants as ohostedcons
-from ovirt_hosted_engine_setup import vds_info
 from ovirt_hosted_engine_setup import pkissh
+from ovirt_hosted_engine_setup import vds_info
+
+import ovirtsdk.api
+import ovirtsdk.infrastructure.errors
+import ovirtsdk.xml
 
 
 def _(m):
@@ -288,6 +284,46 @@ class Plugin(plugin.PluginBase):
             ))
         return cluster, cpu
 
+    def _wait_gluster_service_ready(self, engine_api, cluster_name):
+        self.logger.info(
+            _(
+                "Waiting for cluster '{name}' "
+                "to be configured for gluster..."
+            ).format(
+                name=cluster_name,
+            )
+        )
+        tries = self.VDSM_RETRIES
+        gluster_service = False
+        while not gluster_service and tries > 0:
+            tries -= 1
+            cluster = engine_api.clusters.get(cluster_name)
+            gluster_service = cluster.get_gluster_service()
+            if not gluster_service:
+                self.logger.debug(
+                    'cluster {cluster} cluster.__dict__ {cdict}'.format(
+                        cluster=cluster,
+                        cdict=cluster.__dict__,
+                    )
+                )
+                if tries % 30 == 0:
+                    self.logger.info(
+                        _(
+                            "Waiting for cluster '{name}' "
+                            "to be configured for gluster service..."
+                        ).format(
+                            name=cluster.name,
+                        )
+                    )
+                time.sleep(self.VDSM_DELAY)
+        if not gluster_service and tries == 0:
+            self.logger.error(_(
+                'Timed out while waiting for cluster to be configured '
+                'for gluster service. '
+                'Please check the logs.'
+            ))
+        return cluster, gluster_service
+
     def _wait_network_vlan_ready(self, engine_api, network_id, vlan_id):
         tries = self.VDSM_RETRIES
         updated = False
@@ -446,43 +482,6 @@ class Plugin(plugin.PluginBase):
     def _setup(self):
         self.command.detect('ip')
 
-    @plugin.event(
-        stage=plugin.Stages.STAGE_CUSTOMIZATION,
-        after=(
-            ohostedcons.Stages.DIALOG_TITLES_S_ENGINE,
-        ),
-        before=(
-            ohostedcons.Stages.DIALOG_TITLES_E_ENGINE,
-        ),
-    )
-    def _customization(self):
-        interactive = (
-            self.environment[ohostedcons.EngineEnv.APP_HOST_NAME] is None
-        )
-        while self.environment[ohostedcons.EngineEnv.APP_HOST_NAME] is None:
-            hostname = self.dialog.queryString(
-                name='APP_HOST_NAME',
-                note=_(
-                    'Enter the name which will be used to identify this host'
-                    ' inside the Administrator Portal [@DEFAULT@]: '
-                ),
-                prompt=True,
-                default='hosted_engine_%s' % self.environment[
-                    ohostedcons.StorageEnv.HOST_ID
-                ],
-            )
-            if hostname:
-                self.environment[
-                    ohostedcons.EngineEnv.APP_HOST_NAME
-                ] = hostname
-            else:
-                if interactive:
-                    self.logger.error(_('Please specify a host name'))
-                else:
-                    raise RuntimeError(
-                        _('Empty host name not allowed')
-                    )
-
     @plugin.event(
         stage=plugin.Stages.STAGE_VALIDATION,
     )
@@ -509,6 +508,10 @@ class Plugin(plugin.PluginBase):
                 cluster_name = self.environment[
                     ohostedcons.EngineEnv.HOST_CLUSTER_NAME
                 ]
+                if not self.environment[ohostedcons.EngineEnv.APP_HOST_NAME]:
+                    self.environment[
+                        ohostedcons.EngineEnv.APP_HOST_NAME
+                    ] = socket.gethostname()
                 self.logger.debug(
                     "Getting the list of available clusters via engine's APIs"
                 )
@@ -551,15 +554,15 @@ class Plugin(plugin.PluginBase):
                 cluster = engine_api.clusters.get(cluster_name)
 
                 conn = self.environment[ohostedcons.VDSMEnv.VDS_CLI]
-                net_info = CachingNetInfo(vds_info.capabilities(conn))
+                caps = vds_info.capabilities(conn)
                 bridge_port = self.environment[
                     ohostedcons.NetworkEnv.BRIDGE_IF
                 ]
-                if bridge_port in net_info.vlans:
+                if bridge_port in caps['vlans']:
                     self.logger.debug(
                         "Updating engine's management network to be vlanned"
                     )
-                    vlan_id = net_info.vlans[bridge_port]['vlanid']
+                    vlan_id = caps['vlans'][bridge_port]['vlanid']
                     self.logger.debug(
                         "Getting engine's management network via engine's APIs"
                     )
@@ -581,6 +584,23 @@ class Plugin(plugin.PluginBase):
                         vlan_id
                     )
 
+                if self.environment[
+                    ohostedcons.StorageEnv.ENABLE_HC_GLUSTER_SERVICE
+                ]:
+                    self.logger.debug(
+                        "Configuring the cluster for gluster service"
+                    )
+                    cluster.set_gluster_service(True)
+                    cluster.update()
+                    c, gluster_ready = self._wait_gluster_service_ready(
+                        engine_api,
+                        cluster_name
+                    )
+                    if not gluster_ready:
+                        raise RuntimeError(_(
+                            'Unable to configure the cluster for gluster'
+                        ))
+
                 self.logger.debug('Adding the host to the cluster')
 
                 engine_api.hosts.add(
